==> wiki3_5_0.zip: wiki3_5_0/plugin/partedit/Install.pm <==
############################################################
#
# WikiڡθФԽǤ褦˳ĥץ饰
#
############################################################
package plugin::partedit::Install;
#use strict;
#==============================================================================
# 󥹥ȡ
#==============================================================================
sub install {
	my $wiki = shift;
	$wiki->add_handler("PARTEDIT","plugin::partedit::PartEdit");
}

#==============================================================================
# Wiki::HTMLParserإåɥ饤(Over-ride)
#==============================================================================
sub Wiki::HTMLParser::l_headline {
	my $self  = shift;
	my $level = shift;
	my $obj   = shift;
	my $wiki  = $self->{wiki};
	my $cgi   = $wiki->get_CGI();
	my $page  = $cgi->param("page");
	
	if($self->{para}==1){
		$self->{html} .= "</p>";
		$self->{para} = 0;
	}
	
	$self->end_list;
	$self->end_verbatim;
	$self->end_table;
	$self->end_quote;
	
	my $pagename = $self->{wiki}->get_title() ;
	my $html  = join("",@$obj);
	
	if(!$self->{main}){
		$self->{html} .= "<h".($level+1).">".$html."</h".($level+1).">\n";
	} else {
		$self->{html} .= "<h".($level+1)."><a name=\"p".$self->{p_cnt}."\">".$html."</a></h".($level+1).">\n";
		if($wiki->can_modify_page($page)){
			$self->{html} .= "<div class=\"partedit\"><a class=\"partedit\" href=\"".
			                 $self->{wiki}->config('script_name')."?action=PARTEDIT&amp;page=".
			                 &Util::url_encode($pagename)."&amp;artno=".$self->{p_cnt}."\">Խ</a></div>\n";
		}
	}
	$self->{p_cnt}++;
}

1;

==> wiki3_5_1.zip: wiki3_5_1/plugin/partedit/Install.pm <==
###############################################################################
#
# WikiڡθФԽǤ褦˳ĥץ饰
#
###############################################################################
package plugin::partedit::Install;
#use strict;
#==============================================================================
# 󥹥ȡ
#==============================================================================
sub install {
	my $wiki = shift;
	$wiki->add_handler("PARTEDIT","plugin::partedit::PartEdit");
}

#==============================================================================
# Wiki::HTMLParserإåɥ饤(Over-ride)
# ŪˤcoreǼۤ褤
#==============================================================================
sub Wiki::HTMLParser::l_headline {
	my $self  = shift;
	my $level = shift;
	my $obj   = shift;
	my $wiki  = $self->{wiki};
	my $cgi   = $wiki->get_CGI();
	my $page  = $cgi->param("page");
	
	if($self->{para}==1){
		$self->{html} .= "</p>";
		$self->{para} = 0;
	}
	
	$self->end_list;
	$self->end_verbatim;
	$self->end_table;
	$self->end_quote;
	
	my $html  = join("",@$obj);
	
	if(!$self->{main}){
		$self->{html} .= "<h".($level+1).">".$html."</h".($level+1).">\n";
		
	} elsif($self->{no_partedit}){
		$self->{html} .= "<h".($level+1)."><a name=\"p".$self->{p_cnt}."\">".$html."</a></h".($level+1).">\n";
		
	} else {
		$self->{html} .= "<h".($level+1)."><a name=\"p".$self->{p_cnt}."\">".$html."</a></h".($level+1).">\n";
		if($wiki->can_modify_page($page)){
			unless(defined($self->{partedit}->{$page})){
				$self->{partedit}->{$page} = 0;
			} else {
				$self->{partedit}->{$page}++;
			}
			$self->{html} .= "<div class=\"partedit\"><a class=\"partedit\" href=\"".
			                 $self->{wiki}->config('script_name')."?action=PARTEDIT".
			                 "&amp;page=".&Util::url_encode($page).
			                 "&amp;artno=".$self->{partedit}->{$page}."\">Խ</a></div>\n";
		}
	}
	$self->{p_cnt}++;
}

1;
